@@ -5,40 +5,35 @@ use Moo;
 use Catmandu::Store::DBI::Iterator;
 use namespace::clean;
 
-our $VERSION = "0.0511";
+our $VERSION = "0.06";
 
 my $default_mapping = {
     _id => {
-        column => 'id',
-        type => 'string',
-        index => 1,
+        column   => 'id',
+        type     => 'string',
+        index    => 1,
         required => 1,
-        unique => 1,
+        unique   => 1,
     },
-    _data => {
-        column => 'data',
-        type => 'binary',
-        serialize => 'all',
-    }
+    _data => {column => 'data', type => 'binary', serialize => 'all',}
 };
 
-has mapping => (
-    is => 'ro',
-    default => sub { +{%$default_mapping} },
-);
+has mapping => (is => 'ro', default => sub {+{%$default_mapping}},);
 
 has _iterator => (
-    is => 'ro',
-    lazy => 1,
+    is      => 'ro',
+    lazy    => 1,
     builder => '_build_iterator',
-    handles => [qw(
-        generator
-        count
-        slice
-        select
-        detect
-        first
-    )],
+    handles => [
+        qw(
+            generator
+            count
+            slice
+            select
+            detect
+            first
+            )
+    ],
 );
 
 with 'Catmandu::Bag';
@@ -47,6 +42,7 @@ with 'Catmandu::Serializer';
 sub BUILD {
     my ($self) = @_;
     $self->_normalize_mapping;
+
     # TODO should happen lazily;
     $self->store->handler->create_table($self);
 }
@@ -73,11 +69,13 @@ sub _build_iterator {
 
 sub get {
     my ($self, $id) = @_;
-    my $store = $self->store;
-    my $dbh = $store->dbh;
-    my $q_name = $dbh->quote_identifier($self->name);
-    my $q_id_field = $dbh->quote_identifier( $self->mapping->{_id}->{column} );
-    my $sth = $dbh->prepare_cached("SELECT * FROM ${q_name} WHERE ${q_id_field}=?")
+    my $store      = $self->store;
+    my $dbh        = $store->dbh;
+    my $q_name     = $dbh->quote_identifier($self->name);
+    my $q_id_field = $dbh->quote_identifier($self->mapping->{_id}->{column});
+    my $sth
+        = $dbh->prepare_cached(
+        "SELECT * FROM ${q_name} WHERE ${q_id_field}=?")
         or Catmandu::Error->throw($dbh->errstr);
     $sth->execute($id) or Catmandu::Error->throw($sth->errstr);
     my $row = $sth->fetchrow_hashref;
@@ -93,22 +91,23 @@ sub add {
 
 sub delete {
     my ($self, $id) = @_;
-    my $store = $self->store;
-    my $dbh = $store->dbh;
-    my $q_name = $dbh->quote_identifier($self->name);
-    my $q_id_field = $dbh->quote_identifier( $self->mapping->{_id}->{column} );
-    my $sth = $dbh->prepare_cached("DELETE FROM ${q_name} WHERE ${q_id_field}=?")
-      or Catmandu::Error->throw($dbh->errstr);
+    my $store      = $self->store;
+    my $dbh        = $store->dbh;
+    my $q_name     = $dbh->quote_identifier($self->name);
+    my $q_id_field = $dbh->quote_identifier($self->mapping->{_id}->{column});
+    my $sth
+        = $dbh->prepare_cached("DELETE FROM ${q_name} WHERE ${q_id_field}=?")
+        or Catmandu::Error->throw($dbh->errstr);
     $sth->execute($id) or Catmandu::Error->throw($sth->errstr);
     $sth->finish;
 }
 
 sub delete_all {
     my ($self) = @_;
-    my $store = $self->store;
-    my $dbh = $store->dbh;
+    my $store  = $self->store;
+    my $dbh    = $store->dbh;
     my $q_name = $dbh->quote_identifier($self->name);
-    my $sth = $dbh->prepare_cached("DELETE FROM ${q_name}")
+    my $sth    = $dbh->prepare_cached("DELETE FROM ${q_name}")
         or Catmandu::Error->throw($dbh->errstr);
     $sth->execute or Catmandu::Error->throw($sth->errstr);
     $sth->finish;
@@ -117,7 +116,7 @@ sub delete_all {
 sub _row_to_data {
     my ($self, $row) = @_;
     my $mapping = $self->mapping;
-    my $data = {};
+    my $data    = {};
 
     for my $key (keys %$mapping) {
         my $map = $mapping->{$key};
@@ -133,7 +132,7 @@ sub _row_to_data {
         }
         if ($map->{type} eq "datetime") {
 
-            my($date,$time) = split ' ', $val;
+            my ($date, $time) = split ' ', $val;
             $val = "${date}T${time}Z";
 
         }
@@ -147,7 +146,7 @@ sub _data_to_row {
     my ($self, $data) = @_;
     $data = {%$data};
     my $mapping = $self->mapping;
-    my $row = {};
+    my $row     = {};
     my $serialize_all_column;
 
     for my $key (keys %$mapping) {
@@ -163,7 +162,7 @@ sub _data_to_row {
         if ($map->{type} eq "datetime") {
 
             chop($val);
-            $val = join(' ',split('T',$val));
+            $val = join(' ', split('T', $val));
 
         }
         $row->{$map->{column}} = $val // next;
