@@ -5,22 +5,25 @@ use DBD::Pg ();
 use Moo;
 use namespace::clean;
 
-our $VERSION = "0.0511";
+our $VERSION = "0.06";
 
 with 'Catmandu::Store::DBI::Handler';
 
 sub _column_sql {
-    my ($self, $map,$bag) = @_;
+    my ($self, $map, $bag) = @_;
     my $col = $map->{column};
     my $dbh = $bag->store->dbh;
-    my $sql = $dbh->quote_identifier($col)." ";
+    my $sql = $dbh->quote_identifier($col) . " ";
     if ($map->{type} eq 'string') {
         $sql .= 'TEXT';
-    } elsif ($map->{type} eq 'integer') {
+    }
+    elsif ($map->{type} eq 'integer') {
         $sql .= 'INTEGER';
-    } elsif ($map->{type} eq 'binary') {
+    }
+    elsif ($map->{type} eq 'binary') {
         $sql .= 'BYTEA';
-    } elsif ($map->{type} eq 'datetime') {
+    }
+    elsif ($map->{type} eq 'datetime') {
         $sql .= 'TIMESTAMP';
     }
     if ($map->{array}) {
@@ -37,11 +40,11 @@ sub _column_sql {
 
 sub _create_index_sql {
     my ($self, $bag, $map) = @_;
-    my $name = $bag->name;
-    my $col = $map->{column};
-    my $dbh = $bag->store->dbh;
+    my $name  = $bag->name;
+    my $col   = $map->{column};
+    my $dbh   = $bag->store->dbh;
     my $q_col = $dbh->quote_identifier($col);
-    my $sql = <<SQL;
+    my $sql   = <<SQL;
 DO \$\$
 BEGIN
 
@@ -63,12 +66,14 @@ SQL
 sub create_table {
     my ($self, $bag) = @_;
     my $mapping = $bag->mapping;
-    my $name = $bag->name;
-    my $dbh = $bag->store->dbh;
-    my $q_name = $dbh->quote_identifier($name);
+    my $name    = $bag->name;
+    my $dbh     = $bag->store->dbh;
+    my $q_name  = $dbh->quote_identifier($name);
 
-    my $sql = "CREATE TABLE IF NOT EXISTS $q_name(".
-        join(',', map { $self->_column_sql($_,$bag) } values %$mapping).");";
+    my $sql
+        = "CREATE TABLE IF NOT EXISTS $q_name("
+        . join(',', map {$self->_column_sql($_, $bag)} values %$mapping)
+        . ");";
 
     for my $map (values %$mapping) {
         next if $map->{unique} || !$map->{index};
@@ -81,8 +86,7 @@ sub create_table {
             warn $msg;
         }
     };
-    $dbh->do($sql)
-        or Catmandu::Error->throw($dbh->errstr);
+    $dbh->do($sql) or Catmandu::Error->throw($dbh->errstr);
 }
 
 # see
@@ -91,25 +95,30 @@ sub create_table {
 # https://rt.cpan.org/Public/Bug/Display.html?id=13180
 sub add_row {
     my ($self, $bag, $row) = @_;
-    my $mapping = $bag->mapping;
-    my $dbh = $bag->store->dbh;
-    my $id_col = $mapping->{_id}{column};
+    my $mapping  = $bag->mapping;
+    my $dbh      = $bag->store->dbh;
+    my $id_col   = $mapping->{_id}{column};
     my $q_id_col = $dbh->quote_identifier($id_col);
     my %binary_cols;
     for my $map (values %$mapping) {
         $binary_cols{$map->{column}} = 1 if $map->{type} eq 'binary';
     }
-    my $id = $row->{$id_col};
-    my @cols = keys %$row;
-    my @q_cols = map { $dbh->quote_identifier($_) } @cols;
-    my @vals = values %$row;
-    my $name = $bag->name;
+    my $id     = $row->{$id_col};
+    my @cols   = keys %$row;
+    my @q_cols = map {$dbh->quote_identifier($_)} @cols;
+    my @vals   = values %$row;
+    my $name   = $bag->name;
     my $q_name = $dbh->quote_identifier($name);
-    my $insert_sql = "INSERT INTO $q_name(".join(',', @q_cols).") SELECT ".
-        join(',', ('?') x @cols).
-        " WHERE NOT EXISTS (SELECT 1 FROM $q_name WHERE $q_id_col=?)";
-    my $update_sql = "UPDATE $q_name SET ".join(',', map { "$_=?" } @q_cols).
-        " WHERE $q_id_col=?";
+    my $insert_sql
+        = "INSERT INTO $q_name("
+        . join(',', @q_cols)
+        . ") SELECT "
+        . join(',', ('?') x @cols)
+        . " WHERE NOT EXISTS (SELECT 1 FROM $q_name WHERE $q_id_col=?)";
+    my $update_sql
+        = "UPDATE $q_name SET "
+        . join(',', map {"$_=?"} @q_cols)
+        . " WHERE $q_id_col=?";
 
     my $sth = $dbh->prepare_cached($update_sql)
         or Catmandu::Error->throw($dbh->errstr);
@@ -118,12 +127,13 @@ sub add_row {
         my $col = $cols[$i];
         my $val = $vals[$i];
         if ($binary_cols{$col}) {
-            $sth->bind_param($i+1, $val, {pg_type => DBD::Pg->PG_BYTEA});
-        } else {
-            $sth->bind_param($i+1, $val);
+            $sth->bind_param($i + 1, $val, {pg_type => DBD::Pg->PG_BYTEA});
+        }
+        else {
+            $sth->bind_param($i + 1, $val);
         }
     }
-    $sth->bind_param($i+1, $id);
+    $sth->bind_param($i + 1, $id);
     $sth->execute or Catmandu::Error->throw($sth->errstr);
 
     unless ($sth->rows) {
@@ -135,12 +145,14 @@ sub add_row {
             my $col = $cols[$i];
             my $val = $vals[$i];
             if ($binary_cols{$col}) {
-                $sth->bind_param($i+1, $val, {pg_type => DBD::Pg->PG_BYTEA});
-            } else {
-                $sth->bind_param($i+1, $val);
+                $sth->bind_param($i + 1, $val,
+                    {pg_type => DBD::Pg->PG_BYTEA});
+            }
+            else {
+                $sth->bind_param($i + 1, $val);
             }
         }
-        $sth->bind_param($i+1, $id);
+        $sth->bind_param($i + 1, $id);
         $sth->execute or Catmandu::Error->throw($sth->errstr);
     }
     $sth->finish;
